@@ -1,7 +1,7 @@
 package Mail::DKIM::PrivateKey;
 use strict;
 use warnings;
-our $VERSION = '1.20230212'; # VERSION
+our $VERSION = '1.20230630'; # VERSION
 # ABSTRACT: a private key loaded in memory for DKIM signing
 
 # Copyright 2005-2007 Messiah College. All rights reserved.
@@ -15,6 +15,8 @@ our $VERSION = '1.20230212'; # VERSION
 use base 'Mail::DKIM::Key';
 use Carp;
 *calculate_EM = \&Mail::DKIM::Key::calculate_EM;
+use Crypt::OpenSSL::RSA;
+use Crypt::PK::Ed25519;
 
 
 sub load {
@@ -51,14 +53,9 @@ sub load {
 }
 
 
-sub convert {
-    use Crypt::OpenSSL::RSA;
-
+sub _convert_rsa {
     my $self = shift;
 
-    $self->data
-      or return;
-
     # have to PKCS1ify the privkey because openssl is too finicky...
     my $pkcs = "-----BEGIN RSA PRIVATE KEY-----\n";
 
@@ -74,10 +71,10 @@ sub convert {
     eval {
         local $SIG{__DIE__};
         $cork = new_private_key Crypt::OpenSSL::RSA($pkcs);
-	1
+    1
     } || do {
-	$self->errorstr($@);
-	return;
+        $self->errorstr($@);
+        return;
     };
 
     $cork
@@ -88,10 +85,56 @@ sub convert {
     #		return;
 
     $self->cork($cork);
-
     return 1;
 }
 
+sub _convert_ed25519 {
+    my $self = shift;
+    my $cork;
+
+    eval {
+        local $SIG{__DIE__};
+        $cork = new Crypt::PK::Ed25519;
+
+        # Prepend/append with PEM boilerplate
+        my $pem = "-----BEGIN ED25519 PRIVATE KEY-----\n";
+        $pem .= $self->data;
+        $pem .= "\n";
+        $pem .= "-----END ED25519 PRIVATE KEY-----\n";
+
+        # Pass PEM text buffer
+        $cork->import_key(\$pem)
+            or die 'failed to load Ed25519 private key';
+
+        # Alternatively, import_raw_key() could be used,
+        # but requires the 32-byte key, which must be extracted
+        # from the ASN.1 structure first.
+
+    1
+    } || do {
+        $self->errorstr($@);
+        return;
+    };
+
+    $cork
+      or return;
+
+    $self->cork($cork);
+    return 1;
+}
+
+sub convert {
+    my $self = shift;
+
+    $self->data
+      or return;
+
+    return $self->_convert_rsa if $self->{TYPE} eq 'rsa';
+    return $self->_convert_ed25519 if $self->{TYPE} eq 'ed25519';
+    self->errorstr('unsupported key type');
+    return;
+}
+
 #deprecated
 sub sign {
     my $self = shift;
@@ -108,18 +151,38 @@ sub sign_sha1_digest {
 }
 
 
-sub sign_digest {
+sub _sign_digest_rsa {
     my $self = shift;
     my ( $digest_algorithm, $digest ) = @_;
 
     my $rsa_priv = $self->cork;
     $rsa_priv->use_no_padding;
-
     my $k = $rsa_priv->size;
     my $EM = calculate_EM( $digest_algorithm, $digest, $k );
     return $rsa_priv->decrypt($EM);
 }
 
+sub _sign_digest_ed25519 {
+    my $self = shift;
+    my ( $digest_algorithm, $digest ) = @_;
+
+    my $ed = $self->cork;
+    if ( !$ed ) {
+        $@ = $@ ne '' ? "Ed25519 failed: $@" : 'Ed25519 unknown problem';
+        die;
+    }
+    return $ed->sign_message($digest);
+}
+
+sub sign_digest {
+    my $self = shift;
+    my ( $digest_algorithm, $digest ) = @_;
+
+    return $self->_sign_digest_rsa($digest_algorithm, $digest) if $self->{TYPE} eq 'rsa';
+    return $self->_sign_digest_ed25519($digest_algorithm, $digest) if $self->{TYPE} eq 'ed25519';
+    die 'unsupported key type';
+}
+
 __END__
 
 =pod
@@ -132,7 +195,7 @@ Mail::DKIM::PrivateKey - a private key loaded in memory for DKIM signing
 
 =head1 VERSION
 
-version 1.20230212
+version 1.20230630
 
 =head1 SYNOPSIS
 
